---
title: PortOne X SMARTRO 제휴 혜택 안내
category: 이벤트
tags:
  - 공통
  - 이벤트
searchTags:
  - 추천패키지
  - smartro
  - 알림톡
  - 법인폰
  - 스마트로
  - 가입비무료
datetime: 2024-06-28T06:34:54.297Z
---



포트원을 통해 스마트로를 사용하고 있다면, KT 법인폰 & 알림톡 혜택을 제공합니다.

2026\. 1. 10

스타트업에게 꼭 필요한 서비스 <Highlight text="포트원" />과 함께 누리세요!
---------------------------------------------------

### 포트원을 통해 SMARTRO(스마트로)를 사용하고 있다면 <Highlight text="KT 법인폰 & 알림톡" /> 혜택을 받을 수 있습니다.

### **스마트로(SMARTRO)는 어떤 서비스를 제공하나요?**

스마트로 KT그룹의 통신-금융 컨버런스 사업을 주도합니다.
국내/외 대표 간편결제, 스마트로페이를 통해 신용카드, 간편결제 및 비대면 결제 등 다양한 결제 서비스를 제공하고 있습니다.

### **어떤 혜택을 받을 수 있나요?**

�&#xDCCC;_&#xD574;당 혜택은 결제대행사 스마트로를 계약 혹은 이용중인 고객사에 한해 제공됩니다._

#### ☝️**혜택 1. 알림톡 건당 3.8원 제공**

개인화된 메세지 발송부터 홍보 문자까지 사업을 운영하는데 꼭 필요한 알림톡을 포트원 제휴 혜택가로 이용할 수 있습니다.

#### ✌️**혜택 2. KT 법인폰 혜택 제공**

대기업만 사용하던 법인폰 포트원을 통해 중소기업 외 소규모 사업장도 법인폰을 개통할 수 있습니다.

통신 비용 절감 및 업무 효율성 증가를 위해 많은 기업이 도입하고 있는 법인폰 서비스를 최대 40% 할인된 기업 특가 요금으로 이용해보세요.

<Callout title="👀 법인폰을 쓰면 어떤 점이 좋을까요?" content="✅ 법인/사용자 모두 통신 비용 절감 효과
✅ 업무/개인 전용폰 분리로 업무 효율 제고와 워라밸 보장
✅ 직원 퇴사/인사 이동 시, 법인폰 인수인계를 통한 업무 연속성 보장
✅ 업무용 APP 법인폰 설치로 회사 정보 보안 유지 가능
✅ 법인폰 수/발신 시 V컬러링, 발신정보알림 부가서비스를 통해 기업 홍보 기능 추가" />

<Callout title="✨ 국내 유수기업들은 어떻게 사용하고 있을까요?" content="[물류기업] 쿠*풀필먼트
🗂️직원의 데이터 사용량/통화량 등 일괄 파악이 가능해 법인폰 전체 단말 컨트롤로 30%이상 비용 절감 효과
[판매기업] 테*라 코리아
📞 전화 응대가 많은 영업직군의 경우, 법인폰 지원으로 통신비 절감 효과
[물류기업] (주)롤*
😊휴무일 수신 전화 원천 차단을 통해 직원 워라밸 보호, 카카오톡 업무 메신저 분리로 사생활 침해 방지 효과" />

### **혜택을 받으려면 어떻게 신청하나요?**

<Callout title="🎉 포트원 추천패키지를 통한 PG 가입비 무료 혜택 이벤트 진행중" />

1️⃣ 포트원을 통해 PG 신청을 진행합니다.

<Indent level="1">

① 포트원 전자결제 신청을 위한 회원가입을 진행합니다.\
② '전자결제 신청'을 진행합니다.\
③ 비즈니스 인증 완료 후, 결제서비스 신청 단계에서 스마트로를 선택합니다.\
✔️ 포트원을 통해 스마트로를 이용하고 있는 고객사라면, 3번부터 진행해주세요😊

</Indent>

2️⃣ SMARTRO(스마트로) PG 계약을 완료합니다.\
3️⃣ 스마트로 제휴 혜택을 신청합니다.

<Callout title="💌 알림톡 서비스" content="PG 계약 시, 스마트로에서 고객사에게 별도 안내드립니다.
계약 이후 혜택을 제공받고 싶을 경우, 아래 정보를 기입해 전달주세요.

⚙️알림톡 제휴 신청 접수처 bkkim@smartro.co.kr
✔️포트원 계약 고객사(사업자) 명
✔️담당자 정보 (성함/ 이메일/ 전화번호)" />

<Callout title="📞 법인폰 서비스 " content="포트원 고객을 위한 전용페이지(클릭↗️)를 통해 신청해주세요. 
⚙️법인폰 서비스 문의 02-2040-5151" />

### **제휴혜택 FAQ**

#### Q. 스마트로를 이미 사용하고 있습니다. 혜택을 받을 수 있나요?

<Callout content="네. 가능합니다.
포트원을 통해 스마트로를 이용하고 계신 모든 고객사를 대상으로 제공되는 혜택입니다!
3️⃣제휴신청 을 참고해 원하시는 제휴혜택을 신청해주세요!" />

